@@ -7,7 +7,9 @@ from .types import (
     string_to_type,
     type_to_string,
     DocstringParserResult,
+    TypeNotFoundError,
     Callable,
+    cast_to_type,
 )
 
 
@@ -55,8 +57,12 @@ def _unify_parser_results(
             if param["default"].startswith(("`", "'", '"')):
                 param["default"] = param["default"][1:-1]
         if "default" in param and "type" in param:
-            param["default"] = string_to_type(param["type"])(param["default"])
-
+            try:
+                param["default"] = cast_to_type(
+                    param["default"], string_to_type(param["type"])
+                )
+            except (ValueError, TypeNotFoundError):
+                pass
         if "type" in param:
             param["type"] = type_to_string(param["type"])
 
@@ -472,13 +478,19 @@ def parse_numpy_docstring(docstring: str) -> DocstringParserResult:
         sections[section_name] = section_content.strip().strip("-").strip()
 
     # Process Parameters section
-    if sections["Parameters"]:
-
+    if "Parameters" in sections:
         params = []
         current_param = None
+        current_param_intendation = 0
+        current_intendation = 0
         for line in sections["Parameters"].split("\n"):
-            param_match = re.match(r"\s*([\w,\s]+)\s*:\s*(.+)", line)
-            if param_match and param_match.group(1).strip():
+            param_match = re.match(r"\s*([\w,\s\*\`\"\']+)\s*:\s*(.+)", line)
+            if (
+                param_match
+                and param_match.group(1).strip()
+                and " " not in param_match.group(1).replace(", ", ",").strip()
+                and (len(line) - len(line.lstrip()) <= current_intendation)
+            ):
                 if current_param:
                     # Add the current parameter to the list
                     if len(current_param["name"].split(",")) > 1:
@@ -486,15 +498,27 @@ def parse_numpy_docstring(docstring: str) -> DocstringParserResult:
                             params.append({**current_param, "name": n.strip()})
                     else:
                         params.append(current_param)
+                stype = param_match.group(2)
+                try:
+                    stype = string_to_type(stype)
+                except Exception:
+                    pass
                 current_param = FunctionInputParam(
-                    name=param_match.group(1).strip(),
-                    type=param_match.group(2),
+                    name=param_match.group(1)
+                    .replace("`", "")
+                    .replace("'", "'")
+                    .replace('"', "")
+                    .strip(),
+                    type=stype,
                     description="",
                     optional="optional" in param_match.group(2),
                 )
+                current_param_intendation = len(line) - len(line.lstrip())
+                current_intendation = current_param_intendation
             elif current_param:
                 # Continuation of a parameter description
                 current_param["description"] += line.strip() + " "
+                current_intendation = len(line) - len(line.lstrip())
         if current_param:
             # Add the current parameter to the list
             if len(current_param["name"].split(",")) > 1:
@@ -506,12 +530,18 @@ def parse_numpy_docstring(docstring: str) -> DocstringParserResult:
         res["input_params"] = sections["Parameters"]
 
     # Process Returns section
-    if sections["Returns"]:
+    if "Returns" in sections:
         params = []
         current_param = None
+        current_intendation = 0
         for line in sections["Returns"].split("\n"):
-            param_match = re.match(r"\s*([\w,\s]+)\s*:\s*(.+)", line)
-            if param_match and param_match.group(1).strip():
+            param_match = re.match(r"\s*([\w,\s\-\_]+)\s*:\s*(.+)", line)
+            if (
+                param_match
+                and param_match.group(1).strip()
+                and " " not in param_match.group(1).replace(", ", ",").strip()
+                and (len(line) - len(line.lstrip()) <= current_intendation)
+            ):
                 if current_param:
                     # Add the current parameter to the list
                     if len(current_param["name"].split(",")) > 1:
@@ -519,14 +549,22 @@ def parse_numpy_docstring(docstring: str) -> DocstringParserResult:
                             params.append({**current_param, "name": n.strip()})
                     else:
                         params.append(current_param)
+                stype = param_match.group(2)
+                try:
+                    stype = string_to_type(stype)
+                except Exception:
+                    pass
                 current_param = FunctionOutputParam(
                     name=param_match.group(1).strip(),
-                    type=param_match.group(2),
+                    type=stype,
                     description="",
                 )
+                current_param_intendation = len(line) - len(line.lstrip())
+                current_intendation = current_param_intendation
             elif current_param:
                 # Continuation of a parameter description
                 current_param["description"] += line.strip() + " "
+                current_intendation = len(line) - len(line.lstrip())
         if current_param:
             # Add the current parameter to the list
             if len(current_param["name"].split(",")) > 1:
